/**********************
* WARNING
* Running this code sample will cost you Browshot credits
***********************/

const browshot = require('browshot');
const fs = require("fs");

var client = new browshot('my_api_key');

var interval;

// all default parameters, instance_id = 12 (free)
client.screenshotCreate(
	{url: 'http://www.google.com/', instance_id: 12, size: 'page' }, 
	function(screenshot) {
		// If the screenshot is already in cache, it could be finished already. Otherwise, wait longer
		if (screenshot.status == 'error') {
			console.log(`Screenshot #${screenshot.id} failed: ${screenshot.error}`);
		}
		else if (screenshot.status == 'finished') {
			screenshotFinished(screenshot);
		}
		else {
			interval = setInterval(checkScreenshot, 1000 * 10, screenshot.id);
		}
	}
);


function checkScreenshot(id) {
	client.screenshotInfo(id, { }, function(screenshot) {
		if (screenshot.status == 'error') {
			clearInterval(interval);
			
			console.log(`Screenshot #${screenshot.id} failed: ${screenshot.error}`);
		}
		else if (screenshot.status == 'finished') {
			clearInterval(interval);
			
			screenshotFinished(screenshot);
		}
		else {
			console.log(`Waiting for screenshot #${screenshot.id} to finish...`);
		}
	});
}

function screenshotFinished(screenshot) {
	// request the thumbnail
	client.screenshotThumbnail(screenshot.id, { }, function(image) {
		fs.writeFile("browshot.png", image, (err) => {
			if (err) {
				console.log(`Failed to write image to browshot.png: ${err}`);
			}
			else {
				console.log("Image saved to browshot.png");
			}
		});
	});
}

// you can combine several calls into 1: screenshot_create + screenshot_host
client.screenshotCreate({
		url: 'https://browshot.com/',
		instance_id: 24, // premium
		screen_width: 1600, // wide screen
		screen_height: 1200, 
		size: 'page', // full page
		delay: 25, // greater delay if the page si very longer
		hosting: 's3', // make sure you have set up your S3 bucket with the right ACL
		hosting_bucket: 'my_bucket',
		hosting_file: 'myfile.png', // can be omitted
		hosting_width: 400, // thumbnail 400px wide
	}, function() {});


// Make multiple screenshots of the same page (loaded once)
client.screenshotCreate({
		url: 'https://youtube.com/',
		instance_id: 24, 		// premium
		shots: 5 ,          // 5 screenshots
		shot_interval: 10, // every 10 seconds
		screen_width: 1280,
		screen_height: 1024,
	}, function() { });